pub(crate) struct Immut<'a>(PhantomData<&'a ()>);Tuple Fields
0: PhantomData<&'a ()>Trait Implementations
Sourceimpl<'a> BorrowType for Immut<'a>
impl<'a> BorrowType for Immut<'a>
Sourceconst TRAVERSAL_PERMIT: bool = true
const TRAVERSAL_PERMIT: bool = true
If node references of this borrow type allow traversing to other
nodes in the tree, this constant is set to
true. It can be used
for a compile-time assertion.Auto Trait Implementations
impl<'a> Freeze for Immut<'a>
impl<'a> RefUnwindSafe for Immut<'a>
impl<'a> Send for Immut<'a>
impl<'a> Sync for Immut<'a>
impl<'a> Unpin for Immut<'a>
impl<'a> UnsafeUnpin for Immut<'a>
impl<'a> UnwindSafe for Immut<'a>